@@ -16,7 +16,7 @@ import logging
 import os
 import re
 
-__version__ = '1.37.1'
+__version__ = '1.38.13'
 
 
 class NullHandler(logging.Handler):
@@ -62,8 +62,8 @@ _xform_cache = {
         'AssociateWhatsAppBusinessAccount',
         '-',
     ): 'associate-whatsapp-business-account',
-    ('DeleteWhatsAppMessageMedia', '_'): 'delete_whatsapp_media_message',
-    ('DeleteWhatsAppMessageMedia', '-'): 'delete-whatsapp-media-message',
+    ('DeleteWhatsAppMessageMedia', '_'): 'delete_whatsapp_message_media',
+    ('DeleteWhatsAppMessageMedia', '-'): 'delete-whatsapp-message-media',
     (
         'DisassociateWhatsAppBusinessAccount',
         '_',
